@@ -2,7 +2,7 @@
  * gtksourcetypes.h
  * This file is part of GtkSourceView
  *
- * Copyright (C) 2012-2014 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2012-2016 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,11 +30,17 @@
 #  endif
 #endif
 
-#include <gio/gio.h>
+#include <glib.h>
 #include <gtksourceview/gtksourceversion.h>
 
 G_BEGIN_DECLS
 
+/* This header exists to avoid cycles in header inclusions, when header A needs
+ * the type B and header B needs the type A. For an alternative way to solve
+ * this problem (in C11), see:
+ * https://bugzilla.gnome.org/show_bug.cgi?id=679424#c20
+ */
+
 typedef struct _GtkSourceBuffer			GtkSourceBuffer;
 typedef struct _GtkSourceCompletionContext	GtkSourceCompletionContext;
 typedef struct _GtkSourceCompletion		GtkSourceCompletion;
@@ -52,73 +58,24 @@ typedef struct _GtkSourceGutterRendererPixbuf	GtkSourceGutterRendererPixbuf;
 typedef struct _GtkSourceGutterRendererText	GtkSourceGutterRendererText;
 typedef struct _GtkSourceLanguage		GtkSourceLanguage;
 typedef struct _GtkSourceLanguageManager	GtkSourceLanguageManager;
+typedef struct _GtkSourceMap			GtkSourceMap;
 typedef struct _GtkSourceMarkAttributes		GtkSourceMarkAttributes;
 typedef struct _GtkSourceMark			GtkSourceMark;
 typedef struct _GtkSourcePrintCompositor	GtkSourcePrintCompositor;
+typedef struct _GtkSourceRegion			GtkSourceRegion;
 typedef struct _GtkSourceSearchContext		GtkSourceSearchContext;
 typedef struct _GtkSourceSearchSettings		GtkSourceSearchSettings;
+typedef struct _GtkSourceSpaceDrawer		GtkSourceSpaceDrawer;
 typedef struct _GtkSourceStyle			GtkSourceStyle;
 typedef struct _GtkSourceStyleScheme		GtkSourceStyleScheme;
+typedef struct _GtkSourceStyleSchemeChooser	GtkSourceStyleSchemeChooser;
+typedef struct _GtkSourceStyleSchemeChooserButton GtkSourceStyleSchemeChooserButton;
+typedef struct _GtkSourceStyleSchemeChooserWidget GtkSourceStyleSchemeChooserWidget;
 typedef struct _GtkSourceStyleSchemeManager	GtkSourceStyleSchemeManager;
 typedef struct _GtkSourceTag			GtkSourceTag;
 typedef struct _GtkSourceUndoManager		GtkSourceUndoManager;
 typedef struct _GtkSourceView			GtkSourceView;
 
-/**
- * GtkSourceNewlineType:
- * @GTK_SOURCE_NEWLINE_TYPE_LF: line feed, used on UNIX.
- * @GTK_SOURCE_NEWLINE_TYPE_CR: carriage return, used on Mac.
- * @GTK_SOURCE_NEWLINE_TYPE_CR_LF: carriage return followed by a line feed, used
- *   on Windows.
- *
- * Since: 3.14
- */
-typedef enum
-{
-	GTK_SOURCE_NEWLINE_TYPE_LF,
-	GTK_SOURCE_NEWLINE_TYPE_CR,
-	GTK_SOURCE_NEWLINE_TYPE_CR_LF
-} GtkSourceNewlineType;
-
-/**
- * GTK_SOURCE_NEWLINE_TYPE_DEFAULT:
- *
- * The default newline type on the current OS.
- *
- * Since: 3.14
- */
-#ifdef G_OS_WIN32
-#define GTK_SOURCE_NEWLINE_TYPE_DEFAULT GTK_SOURCE_NEWLINE_TYPE_CR_LF
-#else
-#define GTK_SOURCE_NEWLINE_TYPE_DEFAULT GTK_SOURCE_NEWLINE_TYPE_LF
-#endif
-
-/**
- * GtkSourceCompressionType:
- * @GTK_SOURCE_COMPRESSION_TYPE_NONE: plain text.
- * @GTK_SOURCE_COMPRESSION_TYPE_GZIP: gzip compression.
- *
- * Since: 3.14
- */
-typedef enum
-{
-	GTK_SOURCE_COMPRESSION_TYPE_NONE,
-	GTK_SOURCE_COMPRESSION_TYPE_GZIP
-} GtkSourceCompressionType;
-
-/**
- * GtkSourceBackgroundPatternType:
- * @GTK_SOURCE_BACKGROUND_PATTERN_TYPE_NONE: no pattern
- * @GTK_SOURCE_BACKGROUND_PATTERN_TYPE_GRID: grid pattern
- *
- * Since: 3.16
- */
-typedef enum
-{
-	GTK_SOURCE_BACKGROUND_PATTERN_TYPE_NONE,
-	GTK_SOURCE_BACKGROUND_PATTERN_TYPE_GRID
-} GtkSourceBackgroundPatternType;
-
 G_END_DECLS
 
 #endif /* GTK_SOURCE_TYPES_H */
